import sys
import os
sys.path.append(os.path.dirname(os.path.realpath(__file__)))

import argparse
import subprocess
from entry import *

def main():
    ## Handle input flags
    parser = argparse.ArgumentParser(
        description="Morseet Morseet Morseeeeeeet!!! Convert Morse Code to Text and Text to Morse Code!",
        formatter_class=argparse.RawTextHelpFormatter,
    )
    # Add the flags
    parser.add_argument(
        "-v",
        "--version",
        action="version",
        version="Morseet - version 1.0.0",
        help="Show the version of the program and exit.",
    )
    parser.add_argument(
        "-c",
        "--config",
        action="store_true",
        help="Open the Configuration file in $EDITOR.",
    )
    parser.add_argument(
            "-r",
            "--read",
            metavar="FILE",
            type=str,
            help="Read the specified input file and convert.",
        )

    args = parser.parse_args()
    script_dir = os.path.dirname(os.path.abspath(__file__))
    # Construct the path to config.toml in the same directory
    config_path = os.path.join(script_dir, "config.toml")
    # Check if the config flag was used
    if args.config:
        # Get the default editor from the environment variable
        editor = os.getenv("EDITOR", "nano")  # Default to nano if EDITOR is not set
        # Open the config.toml file in the editor
        subprocess.run([editor, config_path])

    elif args.read:
        # Read the content of the specified input file
        input_file_path = args.read
        try:
            with open(input_file_path, 'r') as file:
                file_content = file.read()
            # Pass the file content to the entry function
            exit_code = file_entry(file_content)
        except FileNotFoundError:
            print(f"Error: The file '{input_file_path}' does not exist.")
            exit_code = 1
    else:
        # Call the entry function if the -c flag is not used
        exit_code = entry()
if __name__ == "__main__":
    main()


import gzip
import os
import platform
import shutil

from setuptools import find_packages, setup


def install_man_page():
    source_path = os.path.join("docs", "man", "morseet.1")
    dest_path = os.path.join("/usr/local/", "share", "man", "man1", "morseet.1.gz")

    # Compress the man page
    with open(source_path, "rb") as src, gzip.open(dest_path, "wb") as dst:
        shutil.copyfileobj(src, dst)


description = """
# morseet
morseet(slang for morse-it) is a command line tool to convert text to morse-code and vice versa. It has various features and customization options making it the only tool
you would go to. 

# Features

- Text to Morse code converter
- Morse Code to text converter
- Easily unserstand minor bugged morse codes
- SOS signal
- See delayed morse code formation real time
- Amazing color scheme customizability

# Installation
To install morseet, please fulfill the dependicies and run the following command:
```bash
pip install morseet
```
To run the command, run the following command:
```bash
morseet
```
And you are good to go!

## Dependencies
- toml
- Other python libraries which will be installed automatically

Visit the Github Repository for more details: https://github.com/AnirudhG07/morseet

# Version
1.0.0

# Note:
1) The tool is developed using Python.
2) This tools is crossplatform for MacOS, Linux, Windows, etc.

"""

setup(
    name="morseet",
    version="1.0.0",
    description="morseet, is a command-line tool to convert morse code to text and vice versa.",
    long_description=description,
    long_description_content_type="text/markdown",
    url="https://github.com/AnirudhG07/morseet",
    author="Anirudh Gupta",
    package_data={
        'morseet': ['config.toml'],
    },
    packages=find_packages(),
    install_requires=["toml"],
    keywords=["terminal", "Morse Code converted", "Encryption", "CLI"],
    python_requires=">=3.11",
    entry_points={
        "console_scripts": [
            "morseet=morseet.main:main",
        ],
    },
    include_package_data=True,
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Topic :: Games/Entertainment",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: POSIX",
        "Operating System :: MacOS",
        "Operating System :: Microsoft :: Windows",
    ],
)




import toml
from morse_dict import morse_dict, reverse_morse_dict
import os

def space_char():
    """
    Opens up config.toml file and reads the space character number
    """
    dir_path = os.path.dirname(os.path.realpath(__file__))
    config_path = os.path.join(dir_path, "config.toml")

    with open(config_path, "r") as f:
        config = toml.load(f)
    # Access the settings
    space = ""
    space_num = config["settings"]["space_char"]
    if space_num != 1:
        space = "......."
    else:
        space = "/"
    return f" {space} "


def text_to_morse(sent: str):
    """
    This function changes any sent to its morse_code
    """
    morsed_sent = ""
    space = space_char()
    err = 0
    invalid_input = set()
    for char in sent:
        if char.lower() in morse_dict or char in [" ", "\n", "\t", "\r"]:
            if char not in [" ", "\n", "\t", "\r"]:
                morsed_sent += morse_dict[char.lower()] + " "
            else:
                morsed_sent += space
        else:
            invalid_input.add(char)
            err = 1
            morsed_sent += " ? "

    return morsed_sent, err, invalid_input


def morse_to_text(morse: str):
    """
    This function converts any morse 1 sent to english text
    """
    text = ""
    err = 0
    invalid_input = set()
    for part in morse.split():
        if part in reverse_morse_dict or part in ["/", ".......", "\n", "\t", "\r"]:
            if part in ["/", "......."]:
                text += " "
            elif part in ["\n", "\t", "\r"]:
                text += part
            else:
                text += reverse_morse_dict[part]
        else:
            text += " ? "
            err = 1
            invalid_input.add(part)

    return text, err, invalid_input



from convert import morse_to_text, text_to_morse
import toml 
import time
import os

welcome = "Welcome to Morse Code Translator. Input the below options to get started:"
option1 = "Text to Morse Code:"
option2 = "Morse Code to Text:"
option3 = "SOS Signal"
option4 = "See morse code with delay"
option5 = "Exit"
select_option = "Select an number among above options: "

error_dict = {
    0: "No err",
    1: "Invalid input character",
}

greetings = """
                                    _
 _ __ ___   ___  _ __ ___  ___  ___| |_
| '_ ` _ \\ / _ \\| '__/ __|/ _ \\/ _ \\ __|
| | | | | | (_) | |  \\__ \\  __/  __/ |_
|_| |_| |_|\\___/|_|  |___/\\___|\\___|\\__|
"""

dir_path = os.path.dirname(os.path.realpath(__file__))
config_path = os.path.join(dir_path, "config.toml")

def format(text:str, code) -> str:
    """
    This function formats the text to be printed
    """
    return f"\033[{code}m{text}\033[0m"

def entry():
    with open(config_path, "r") as f:
        config = toml.load(f)
    # Access the color_schemes
    greet_col = config["color_schemes"]["greeting"]
    mains = config["color_schemes"]["main_strings"]
    option_nums = config["color_schemes"]["option_nums"]
    option_text = config["color_schemes"]["option_text"]
    error_ = config["color_schemes"]["error"]
    success = config["color_schemes"]["success"]

    ####
    print(format(greetings, greet_col))
    print(format(welcome, mains))
    print(f"{format('[1]', option_nums)}", format(option1, option_text))
    print(f"{format('[2]', option_nums)}", format(option2, option_text))
    print(f"{format('[3]', option_nums)}", format(option3, option_text))
    print(f"{format('[4]', option_nums)}", format(option4, option_text))
    print(f"{format('[5]', option_nums)}", format(option5, option_text))

    option = 0
    while True:
        option = int(input(f"\n{select_option}"))
        if 1 <= option <= 5:
            break
        else:
            print(format("Invalid option. Please select an option among 1, 2 or 3.", error_))

    assert 1<= option <= 5, "Invalid option. Option must be 1 to 5"

    error, invalid, output = "No err", set() , ""
    while option != 5:
        if str(option) == "1" or str(option) == "4":
            input_sent = input("Enter English text: ")
            output, err, invalid = text_to_morse(input_sent)
            error = error_dict[err]
            break
        elif str(option) == "2": 
            input_morse = input("Enter Morse code: ")
            output, err, invalid = morse_to_text(input_morse)
            error = error_dict[err]
            break
        elif str(option) == "3":
            output, err, invalid = text_to_morse("SOS")
            error = error_dict[err]
            print(output)
            print(format("\nEmergency exiting! SOS Signal is alarmed. ", error_))
            return 0

    if option == 5:
        print(format("\nThank you for using Morseeeeet! Goodbye!", success))
        return 0
    
    if option == 4:
        delay_unit = config["settings"]["delay_unit"]
        for char in output:
            print(char, end="", flush=True)
            if char == ".":
                time.sleep(delay_unit)
            elif char == "-":
                time.sleep(3*delay_unit)
            else: ## Space
                time.sleep(7*delay_unit)
        print("\n")
    else:
        print(output)

    if error != error_dict[0]:
        print(format(f"\nError: {error} occurred", error_))
        print("Invalid inputs characters received: ", invalid)
    
    replay = input(format("\nWould you like to morseet more? (y/n) ", greet_col))
    if replay.lower() == "y" or replay.lower() == "yes":
        entry()
    elif replay.lower() == "n" or replay.lower() == "no":
        print(format("\nThank you for using Morseeeeet! Goodbye!", success))
    else:
        print(format("Invalid input. Exiting... Goodbye!", error_))

    return 0

def file_entry(file_content: str) -> int:
    with open(config_path, "r") as f:
        config = toml.load(f)
    # Access the color_schemes
    greet_col = config["color_schemes"]["greeting"]
    mains = config["color_schemes"]["main_strings"]
    option_nums = config["color_schemes"]["option_nums"]
    option_text = config["color_schemes"]["option_text"]
    error_ = config["color_schemes"]["error"]
    success = config["color_schemes"]["success"]

    print(format(greetings, greet_col))
    print(format("Welcome to Morse Code Translator. Your input file is successfully been inputted. Select an option: ", mains))

    print(f"{format('[1]', option_nums)}", format(option1, option_text))
    print(f"{format('[2]', option_nums)}", format(option2, option_text))
    print(f"{format('[3]', option_nums)}", format(option3, option_text))
    print(f"{format('[4]', option_nums)}", format("Exit", option_text))

    option = 0
    while True:
        option = int(input(f"\n{select_option}"))
        if 1 <= option <= 4:
            break
        else:
            print(format("Invalid option. Please select an option among 1 to 4.", error_))

    assert 1<= option <= 4, "Invalid option. Option must be 1 to 4"

    error, invalid, output = "No err", set() , ""
    while option != 4:
        if str(option) == "1":
            output, err, invalid = text_to_morse(file_content)
            error = error_dict[err]
            break
        elif str(option) == "2": 
            output, err, invalid = morse_to_text(file_content)
            error = error_dict[err]
            break
        elif str(option) == "3":
            output, err, invalid = text_to_morse("SOS")
            error = error_dict[err]
            print(output)
            print(format("\nEmergency exiting! SOS Signal is alarmed. ", error_))
            return 0

    if str(option) == "4":
        print(format("\nThank you for using Morseeeeet! Goodbye!", success))
        return 0

    print(output)
    if error != error_dict[0]:
        print(format(f"\nError: {error} occurred", error_))
        print("Invalid inputs characters received: ", invalid)
    
    replay = input(format("\nWould you like to morseet more? (y/n) ", greet_col))
    if replay.lower() == "y" or replay.lower() == "yes":
        entry()
    elif replay.lower() == "n" or replay.lower() == "no":
        print(format("\nThank you for using Morseeeeet! Goodbye!", success))
    else:
        print(format("Invalid input. Exiting... Goodbye!", error_))

    return 0